**Example 1: 开启跟踪集**

开启跟踪集

Input: 

```
tccli cloudaudit StartLogging --cli-unfold-argument  \
    --AuditName xxxxx
```

Output: 
```
{
    "Response": {
        "IsSuccess": 1,
        "RequestId": "94ced030-d9df-4fb3-9894-7accd0c29d23"
    }
}
```

